pub struct AgentHandle<T> { /* private fields */ }Expand description
Handle to a spawned agent.
This is returned by spawn() and can be awaited to get the agent’s result.
Implementations
Sourceimpl<T> AgentHandle<T>
impl<T> AgentHandle<T>
Sourcepub async fn result(self) -> SageResult<T>
pub async fn result(self) -> SageResult<T>
Wait for the agent to complete and return its result.
Sourceimpl<T> AgentHandle<T>
impl<T> AgentHandle<T>
Sourcepub async fn send<M>(&self, msg: M) -> SageResult<()>where
M: Serialize,
pub async fn send<M>(&self, msg: M) -> SageResult<()>where
M: Serialize,
Send a message to the agent.
The message will be serialized to JSON and placed in the agent’s mailbox.
Sourcepub async fn send_message(&self, message: Message) -> SageResult<()>
pub async fn send_message(&self, message: Message) -> SageResult<()>
Send a pre-built message to the agent.
This is used by generated code when the message needs additional metadata (like type_name for protocol tracking).