pub struct LlmClient { /* private fields */ }Expand description
Client for making LLM inference calls.
Implementations
Sourceimpl LlmClient
impl LlmClient
Sourcepub async fn infer_string(&self, prompt: &str) -> SageResult<String>
pub async fn infer_string(&self, prompt: &str) -> SageResult<String>
Call the LLM with a prompt and return the raw string response.
Sourcepub async fn infer<T>(&self, prompt: &str) -> SageResult<T>where
T: DeserializeOwned,
pub async fn infer<T>(&self, prompt: &str) -> SageResult<T>where
T: DeserializeOwned,
Call the LLM with a prompt and parse the response as the given type.